% eeg_eegrej() - reject porition of continuous data in an EEGLAB 
%                dataset
%
% Usage:
%   >> EEGOUT = eeg_eegrej( EEGIN, regions );
%
% Inputs:
%   INEEG      - input dataset
%   regions    - array of regions to suppress. number x [beg end]  of 
%                regions. 'beg' and 'end' are expressed in term of points
%                in the input dataset. Size of the array is
%                number x 2 of regions.
%
% Outputs:
%   INEEG      - output dataset with updated data, events latencies and 
%                additional boundary events.
%
% Author: Arnaud Delorme, CNL / Salk Institute, 8 August 2002
%
% See also: eeglab(), eegplot(), pop_rejepoch()

% Copyright (C) 2002 Arnaud Delorme, Salk Institute, arno@salk.edu
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

function [EEG, com] = eeg_eegrej( EEG, regions,probadded);

com = '';
if nargin < 2
	help eeg_eegrej;
	return;
end;
if nargin<3
    probadded = [];
end
if isempty(regions)
	return;
end;
v_added = 0;
if isempty(probadded) || ~probadded
    % For AMICA probabilities...Temporarily add model probabilities as channels
    %-----------------------------------------------------
    if isfield(EEG.etc, 'amica') && ~isempty(EEG.etc.amica) && isfield(EEG.etc.amica, 'v_smooth') && ~isempty(EEG.etc.amica.v_smooth)
        if isfield(EEG.etc.amica, 'num_models') && ~isempty(EEG.etc.amica.num_models)
            if size(EEG.data,2) == size(EEG.etc.amica.v_smooth,2) && size(EEG.data,3) == size(EEG.etc.amica.v_smooth,3) && size(EEG.etc.amica.v_smooth,1) == EEG.etc.amica.num_models
                v_added = 1;
                EEG.data(end+1:end+EEG.etc.amica.num_models,:,:) = EEG.etc.amica.v_smooth;
                EEG.data(end+1:end+EEG.etc.amica.num_models,:,:) = EEG.etc.amica.LLt;
                EEG.nbchan = EEG.nbchan + 2*EEG.etc.amica.num_models;
                if ~isempty(EEG.chanlocs)
                    for i = 1:2*EEG.etc.amica.num_models;
                        EEG.chanlocs(end + 1) = EEG.chanlocs(end);
                    end
                end
            else
                disp('AMICA probabilities not compatible with size of data, probabilties cannot be epoched')
                disp('Load AMICA components before extracting epochs')
                disp('Resuming rejection...')
            end
        end
    end
    % ------------------------------------------------------
end



if isfield(EEG.event, 'latency'),
   	 tmpalllatencies = [ EEG.event.latency ];
else tmpalllatencies = []; 
end;

% handle regions from eegplot
% ---------------------------
if size(regions,2) > 2, regions = regions(:, 3:4); end;

[EEG.data EEG.xmax tmpalllatencies boundevents] = eegrej( EEG.data, ...
												  regions, EEG.xmax-EEG.xmin, tmpalllatencies);
oldEEGpnts = EEG.pnts;
EEG.pnts   = size(EEG.data,2);
EEG.xmax   = EEG.xmax+EEG.xmin;



% For AMICA probabilities;  remove the added model probabilities from
% channels
% -----------------------------------------------------
if v_added
    EEG.etc.amica.LLt = EEG.data(end-EEG.etc.amica.num_models+1:end,:,:);
    EEG.data(end-EEG.etc.amica.num_models+1:end,:,:) = [];
    EEG.etc.amica.v_smooth = EEG.data(end-EEG.etc.amica.num_models+1:end,:,:);
    EEG.nbchan = EEG.nbchan - 2*EEG.etc.amica.num_models;
    EEG.data = EEG.data(1:end-EEG.etc.amica.num_models,:,:);
    if ~isempty(EEG.chanlocs)
                for i = 1:2*EEG.etc.amica.num_models;
                    EEG.chanlocs(end) = [];
                end
    end
end
% ----------------------------------------------------



% add boundary events
% -------------------
if ~isempty(boundevents) % boundevent latencies will be recomputed in the function below
    [ EEG.event ] = eeg_insertbound(EEG.event, oldEEGpnts, regions);
    EEG = eeg_checkset(EEG, 'eventconsistency');
end;

com = sprintf('%s = eeg_eegrej( %s, %s);', inputname(1), inputname(1), vararg2str({ regions })); 
return;
